Assorted spelling fixes

Francois Gouget fgouget at free.fr
Mon Jan 10 05:34:28 CST 2005


Changelog:

  * dlls/ddraw/d3dtexture.c
    dlls/ddraw/d3dviewport.c
    dlls/ddraw/d3ddevice/mesa.c
    dlls/mapi32/prop.c
    dlls/mapi32/tests/prop.c
    dlls/msi/action.c
    dlls/msi/tests/db.c
    dlls/msi/tests/record.c
    include/oleauto.h

    Assorted spelling fixes.


-- 
Francois Gouget         fgouget at free.fr        http://fgouget.free.fr/
      Linux, WinNT, MS-DOS - also known as the Good, the Bad and the Ugly.
-------------- next part --------------
Index: dlls/ddraw/d3dtexture.c
===================================================================
RCS file: /var/cvs/wine/dlls/ddraw/d3dtexture.c,v
retrieving revision 1.67
diff -u -r1.67 d3dtexture.c
--- dlls/ddraw/d3dtexture.c	23 Dec 2004 18:33:44 -0000	1.67
+++ dlls/ddraw/d3dtexture.c	9 Jan 2005 00:34:09 -0000
@@ -889,7 +889,7 @@
 	surf->aux_setcolorkey_cb = gltex_setcolorkey_cb;
 	surf->set_palette = gltex_set_palette;
 
-	/* We are the only one to use the aux_blt and aux_bltfast overides, so no need
+	/* We are the only one to use the aux_blt and aux_bltfast overrides, so no need
 	   to save those... */
 	surf->aux_blt = gltex_blt;
 	surf->aux_bltfast = gltex_bltfast;
Index: dlls/ddraw/d3dviewport.c
===================================================================
RCS file: /var/cvs/wine/dlls/ddraw/d3dviewport.c,v
retrieving revision 1.27
diff -u -r1.27 d3dviewport.c
--- dlls/ddraw/d3dviewport.c	9 Jan 2005 17:35:44 -0000	1.27
+++ dlls/ddraw/d3dviewport.c	9 Jan 2005 23:57:44 -0000
@@ -198,7 +198,7 @@
     memset(&(This->viewports.vp1), 0, sizeof(This->viewports.vp1));
     memcpy(&(This->viewports.vp1), lpData, lpData->dwSize);
 
-    /* Tests on two games shows that these values are never used properly so overide
+    /* Tests on two games show that these values are never used properly so override
        them with proper ones :-)
     */
     This->viewports.vp1.dvMinZ = 0.0;
Index: dlls/ddraw/d3ddevice/mesa.c
===================================================================
RCS file: /var/cvs/wine/dlls/ddraw/d3ddevice/mesa.c,v
retrieving revision 1.166
diff -u -r1.166 mesa.c
--- dlls/ddraw/d3ddevice/mesa.c	9 Jan 2005 17:35:44 -0000	1.166
+++ dlls/ddraw/d3ddevice/mesa.c	9 Jan 2005 23:57:44 -0000
@@ -3153,7 +3153,7 @@
 		x_stretch = (double) (rect.u3.x2 - rect.u1.x1) / (double) width;
 		y_stretch = (double) (rect.u4.y2 - rect.u2.y1) / (double) height;
 
-		TRACE(" using memory to buffer Blt overide.\n");
+		TRACE(" using memory to buffer Blt override.\n");
 
 		ENTER_GL();
 
@@ -3161,7 +3161,7 @@
 		
 		if (upload_surface_to_tex_memory_init(src_impl, 0, &gl_d3d_dev->current_internal_format,
 						      initial, ((dwFlags & DDBLT_KEYSRC) != 0), UNLOCK_TEX_SIZE, UNLOCK_TEX_SIZE) != DD_OK) {
-		    ERR(" unsupported pixel format at memory to buffer Blt overide.\n");
+		    ERR(" unsupported pixel format at memory to buffer Blt override.\n");
 		    LEAVE_GL();
 		    return DDERR_INVALIDPARAMS;
 		}
@@ -3172,7 +3172,7 @@
 		else
 		    glDrawBuffer(GL_BACK);
 
-		/* Now the serious stuff happens. This is basically the same code that for the memory
+		/* Now the serious stuff happens. This is basically the same code as for the memory
 		   flush to frame buffer ... with stretching and different rectangles added :-) */
 		for (y = 0; y < height; y += UNLOCK_TEX_SIZE) {
 		    RECT flush_rect;
@@ -3274,7 +3274,7 @@
     
     if (setup_rect_and_surface_for_blt(This, &buffer_type, (D3DRECT *) &rdst) != DD_OK) return DDERR_INVALIDPARAMS;
 
-    TRACE(" using BltFast memory to frame buffer overide.\n");
+    TRACE(" using BltFast memory to frame buffer override.\n");
     
     ENTER_GL();
     
@@ -3283,7 +3283,7 @@
     if (upload_surface_to_tex_memory_init(src_impl, 0, &gl_d3d_dev->current_internal_format,
 					  initial, (trans & DDBLTFAST_SRCCOLORKEY) != 0,
 					  UNLOCK_TEX_SIZE, UNLOCK_TEX_SIZE) != DD_OK) {
-	ERR(" unsupported pixel format at memory to buffer Blt overide.\n");
+	ERR(" unsupported pixel format at memory to buffer Blt override.\n");
 	LEAVE_GL();
 	return DDERR_INVALIDPARAMS;
     }
@@ -3978,9 +3978,9 @@
 		surf2->aux_blt = d3ddevice_blt;
 		surf2->aux_bltfast = d3ddevice_bltfast;
 		
-		TRACE(" overiding direct surface access.\n");
+		TRACE(" overriding direct surface access.\n");
 	    } else {
-	        TRACE(" no overide.\n");
+	        TRACE(" no override.\n");
 	    }
 	    surf2->d3ddevice = object;
 	}
@@ -4172,7 +4172,7 @@
     opengl_device_caps.dwReserved3 = 0;
     opengl_device_caps.dwReserved4 = 0;
 
-    /* And now some GL overides :-) */
+    /* And now some GL overrides :-) */
     glGetIntegerv(GL_MAX_TEXTURE_SIZE, (GLint *) &opengl_device_caps.dwMaxTextureWidth);
     opengl_device_caps.dwMaxTextureHeight = opengl_device_caps.dwMaxTextureWidth;
     opengl_device_caps.dwMaxTextureAspectRatio = opengl_device_caps.dwMaxTextureWidth;
Index: dlls/mapi32/prop.c
===================================================================
RCS file: /var/cvs/wine/dlls/mapi32/prop.c,v
retrieving revision 1.6
diff -u -r1.6 prop.c
--- dlls/mapi32/prop.c	9 Jan 2005 16:52:51 -0000	1.6
+++ dlls/mapi32/prop.c	9 Jan 2005 23:57:52 -0000
@@ -1636,7 +1636,7 @@
  *           successfully.
  * NOTES
  *  - If MAPI_W_ERRORS_RETURNED is returned, any properties that could not be
- *    retrieved from iface are present in lppProps with thier type
+ *    retrieved from iface are present in lppProps with their type
  *    changed to PT_ERROR and Id unchanged.
  */
 static inline HRESULT WINAPI
@@ -1985,7 +1985,7 @@
 /**************************************************************************
  *  IMAPIProp_GetNamesFromIDs {MAPI32}
  *
- * Get the names of properties from thier identifiers.
+ * Get the names of properties from their identifiers.
  *
  * PARAMS
  *  iface       [I]   IMAPIProp object to operate on
Index: dlls/msi/action.c
===================================================================
RCS file: /var/cvs/wine/dlls/msi/action.c,v
retrieving revision 1.64
diff -u -r1.64 action.c
--- dlls/msi/action.c	7 Jan 2005 17:08:35 -0000	1.64
+++ dlls/msi/action.c	7 Jan 2005 20:14:13 -0000
@@ -716,7 +716,7 @@
  *  The arguments following count are a list of path segments.
  *  A path segment may be NULL.
  *
- *  Path segments will be added with a \ seperating them.
+ *  Path segments will be added with a \ separating them.
  *  A \ will not be added after the last segment, however if the
  *    last segment is NULL, then the last character will be a \
  * 
Index: dlls/msi/tests/db.c
===================================================================
RCS file: /var/cvs/wine/dlls/msi/tests/db.c,v
retrieving revision 1.1
diff -u -r1.1 db.c
--- dlls/msi/tests/db.c	5 Jan 2005 13:26:34 -0000	1.1
+++ dlls/msi/tests/db.c	6 Jan 2005 22:54:34 -0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005 Mike McCormack for Codeweavers
+ * Copyright (C) 2005 Mike McCormack for CodeWeavers
  *
  * A test program for MSI database files.
  *
Index: dlls/msi/tests/record.c
===================================================================
RCS file: /var/cvs/wine/dlls/msi/tests/record.c,v
retrieving revision 1.2
diff -u -r1.2 record.c
--- dlls/msi/tests/record.c	9 Jan 2005 18:24:15 -0000	1.2
+++ dlls/msi/tests/record.c	9 Jan 2005 23:57:54 -0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005 Mike McCormack for Codeweavers
+ * Copyright (C) 2005 Mike McCormack for CodeWeavers
  *
  * A test program for MSI records
  *
Index: include/oleauto.h
===================================================================
RCS file: /var/cvs/wine/include/oleauto.h,v
retrieving revision 1.56
diff -u -r1.56 oleauto.h
--- include/oleauto.h	1 Mar 2004 21:22:59 -0000	1.56
+++ include/oleauto.h	7 Jan 2005 22:53:07 -0000
@@ -207,7 +207,7 @@
 #define VAR_TIMEVALUEONLY       0x001 /* Ignore date portion of VT_DATE */
 #define VAR_DATEVALUEONLY       0x002 /* Ignore time portion of VT_DATE */
 #define VAR_VALIDDATE           0x004
-#define VAR_CALENDAR_HIJRI      0x008 /* Use the Hijri calender */
+#define VAR_CALENDAR_HIJRI      0x008 /* Use the Hijri calendar */
 #define VAR_LOCALBOOL           0x010 /* VT_BOOL<->VT_BSTR: Use localised boolean text */
 #define VAR_FORMAT_NOSUBSTITUTE 0x020 /* Don't change format strings for un-coercable types */
 #define VAR_FOURDIGITYEARS      0x040 /* Always print years with 4 digits */


More information about the wine-patches mailing list
Index: dlls/mapi32/tests/prop.c
===================================================================
RCS file: /var/cvs/wine/dlls/mapi32/tests/prop.c,v
retrieving revision 1.6
diff -u -r1.6 prop.c
--- dlls/mapi32/tests/prop.c	9 Jan 2005 16:52:51 -0000	1.6
+++ dlls/mapi32/tests/prop.c	9 Jan 2005 23:57:53 -0000
@@ -636,7 +636,7 @@
            ptTypes[i]);
 
         pRet = pPpropFindProp(&pvProp, 1u, i ? ptTypes[i-1] : ptTypes[i+1]);
-        ok(pRet == NULL, "PpropFindProp[%ld]: Found non-existing propery\n",
+        ok(pRet == NULL, "PpropFindProp[%ld]: Found non-existent propery\n",
            ptTypes[i]);
     }
 
@@ -868,11 +868,11 @@
            ptTypes[i]);
 
         pRet = pLpValFindProp(PROP_TAG(ptTypes[i], 0u), 1u, &pvProp);
-        ok(pRet == NULL, "LpValFindProp[%ld]: Found non-existing propery id\n",
+        ok(pRet == NULL, "LpValFindProp[%ld]: Found non-existent propery id\n",
            ptTypes[i]);
 
         pRet = pLpValFindProp(PROP_TAG(PT_NULL, 0u), 1u, &pvProp);
-        ok(pRet == NULL, "LpValFindProp[%ld]: Found non-existing propery id/type\n",
+        ok(pRet == NULL, "LpValFindProp[%ld]: Found non-existent propery id/type\n",
            ptTypes[i]);
 
         pRet = pLpValFindProp(PROP_TAG(PT_NULL, 1u), 1u, &pvProp);
@@ -1257,22 +1257,22 @@
     tags.aulPropTag[0] = PR_RESPONSE_REQUESTED;
     sc = IPropData_DeleteProps(lpIProp, (LPSPropTagArray)&tags, &lpProbs);
     ok(sc == E_ACCESSDENIED && !lpProbs,
-       "DeleteProps(non-existant): Expected E_ACCESSDENIED null got 0x%08lX %p\n",
+       "DeleteProps(non-existent): Expected E_ACCESSDENIED null got 0x%08lX %p\n",
        sc, lpProbs);
 
     /* Set access to read and write */
     sc = IPropData_HrSetObjAccess(lpIProp, IPROP_READWRITE);
     ok(sc == S_OK, "SetObjAcess(WRITE): Expected S_OK got 0x%08lX\n", sc);
 
     /* Delete non existant item - No error */
     lpProbs = NULL;
     tags.aulPropTag[0] = PR_RESPONSE_REQUESTED;
     sc = IPropData_DeleteProps(lpIProp, (LPSPropTagArray)&tags, &lpProbs);
     ok(sc == S_OK && !lpProbs,
-       "DeleteProps(non-existant): Expected S_OK null got 0x%08lX %p\n",
+       "DeleteProps(non-existent): Expected S_OK null got 0x%08lX %p\n",
        sc, lpProbs);
 
-    /* Delete existant item (r/o) - No error, but lpProbs populated */
+    /* Delete existing item (r/o) - No error, but lpProbs populated */
     lpProbs = NULL;
     tags.aulPropTag[0] = PR_IMPORTANCE;
     sc = IPropData_DeleteProps(lpIProp, (LPSPropTagArray)&tags, &lpProbs);
@@ -1318,7 +1318,7 @@
     sc = IPropData_HrSetPropAccess(lpIProp, (LPSPropTagArray)&tags, access);
     ok(sc == S_OK, "SetPropAcess(WRITE): Expected S_OK got 0x%08lX\n", sc);
 
-    /* Delete existant item (r/w) - No error, no problems */
+    /* Delete existing item (r/w) - No error, no problems */
     lpProbs = NULL;
     sc = IPropData_DeleteProps(lpIProp, (LPSPropTagArray)&tags, &lpProbs);
     ok(sc == S_OK && !lpProbs,
@@ -1257,22 +1257,22 @@
     ok(sc == S_OK, "SetObjAcess(WRITE): Expected S_OK got 0x%08lX\n", sc);
 
-    /* Delete non existant item - No error */
+    /* Delete non-existent item - No error */
     lpProbs = NULL;
     tags.aulPropTag[0] = PR_RESPONSE_REQUESTED;